@@ -5,16 +5,18 @@
 -- SPDX-License-Identifier: EPL-2.0
 
 -- Domains
-CREATE DOMAIN VALID_STRING 
-AS VARCHAR(20) 
-  DEFAULT 'NO VALUE' 
+CREATE DOMAIN VALID_STRING
+AS VARCHAR(20)
+  DEFAULT 'NO VALUE'
   CHECK (VALUE IS NOT NULL AND CHARACTER_LENGTH(VALUE) > 2);
 
 -- Table using domains
 CREATE TABLE CustomerData
 (
-  Id INTEGER NOT NULL,  
+  CustomerId INTEGER NOT NULL,
+  DataId INTEGER NOT NULL,
   Data VALID_STRING,
-  CONSTRAINT PK_CustomerData PRIMARY KEY (Id)
+  CONSTRAINT PK_CustomerData PRIMARY KEY (CustomerId, DataId),
+  CONSTRAINT FK_Customer FOREIGN KEY (CustomerId) REFERENCES Customers (Id)
 )
 ;
